"use client"

import { useState } from "react"
import Quiz from "@/components/quiz"
import { Button } from "@/components/ui/button"
import { ArrowLeft, AlertTriangle } from "lucide-react"
import Link from "next/link"
import NavBar from "@/components/nav-bar"

// Sample exam questions using the JSON format
const examQuestions = [
  {
    qid: "295",
    question:
      "Cette limite de vitesse s'applique...\n\nA. ... jusqu'au carrefour suivant.\nB. ... jusqu'à ce que vous voyez le panneau \\\"Fin de Zone\\\".",
    correct_answer: "a",
    explanation: "LEÇON 12 – 'La vitesse'. \nJusqu'au carrefour suivant.",
    image_url: "https://examen.gratisrijbewijsonline.be/afbeeldingen/197/295.jpg",
    suggestion: ["... jusqu'au carrefour suivant.", '... jusqu\'à ce que vous voyez le panneau \\"Fin de Zone\\".'],
  },
  {
    qid: "955",
    question: "Pouvez vous circuler sur cet accotement pour croiser un vehicule ?",
    correct_answer: "oui",
    explanation:
      "LEÇON 7 – 'Les piétons'.\nIl ne peut pas sur une piste cyclable ou sur la bande à côté de la ligne imaginaire de la voie destinée au stationnement.",
    image_url: "https://examen.gratisrijbewijsonline.be/afbeeldingen/197/955.jpg",
    suggestion: ["oui", "non"],
  },
  {
    qid: "301",
    question:
      "Quelle est la vitesse maximale autorisée sur autoroute par temps de pluie pour un conducteur ayant son permis depuis plus de 3 ans ?",
    correct_answer: "b",
    explanation: "LEÇON 12 – 'La vitesse'. Sur autoroute, par temps de pluie, la vitesse est limitée à 110 km/h.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: ["90 km/h", "110 km/h", "130 km/h"],
  },
  {
    qid: "302",
    question: "Dans cette situation, qui doit céder le passage ?",
    correct_answer: "c",
    explanation:
      "LEÇON 6 – 'Les priorités'. En l'absence de signalisation spécifique, c'est la règle de la priorité à droite qui s'applique.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: ["Le véhicule A", "Le véhicule B", "Le véhicule qui arrive de la droite"],
  },
  {
    qid: "303",
    question: "Quel est le taux d'alcoolémie maximum autorisé pour un conducteur novice ?",
    correct_answer: "a",
    explanation:
      "LEÇON 13 – 'L'alcool et la conduite'. Pour un conducteur novice (moins de 3 ans de permis), le taux d'alcoolémie maximum est de 0,2 g/l de sang.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: ["0,2 g/l de sang", "0,5 g/l de sang", "0,8 g/l de sang"],
  },
  {
    qid: "304",
    question: "Que signifie ce panneau ?",
    correct_answer: "b",
    explanation:
      "LEÇON 3 – 'La signalisation'. Ce panneau indique la fin d'une limitation de vitesse précédemment imposée.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: ["Fin de toutes les interdictions", "Fin de limitation de vitesse", "Fin d'interdiction de dépasser"],
  },
  {
    qid: "305",
    question: "Quand le feu est orange, vous devez :",
    correct_answer: "a",
    explanation:
      "LEÇON 3 – 'La signalisation'. Lorsque le feu est orange, vous devez vous arrêter si les conditions de sécurité le permettent.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: [
      "Vous arrêter si les conditions de sécurité le permettent",
      "Accélérer pour libérer l'intersection rapidement",
      "Ralentir et passer avec prudence",
    ],
  },
  {
    qid: "306",
    question: "Sur autoroute, quelle est la distance de sécurité minimale à respecter ?",
    correct_answer: "b",
    explanation:
      "LEÇON 12 – 'La vitesse'. Sur autoroute, il est recommandé de respecter une distance de sécurité d'au moins 2 secondes de trajet.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: ["1 seconde de trajet", "2 secondes de trajet", "3 secondes de trajet"],
  },
  {
    qid: "307",
    question: "Que faire en cas de crevaison sur autoroute ?",
    correct_answer: "b",
    explanation:
      "LEÇON 14 – 'Les situations d'urgence'. En cas de crevaison sur autoroute, il est recommandé de mettre le triangle de signalisation et d'appeler les secours plutôt que de changer la roue vous-même sur la bande d'arrêt d'urgence, ce qui est dangereux.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: [
      "Changer la roue sur la bande d'arrêt d'urgence",
      "Mettre le triangle de signalisation et appeler les secours",
      "Sortir à la prochaine aire de service si possible",
    ],
  },
  {
    qid: "308",
    question: "Quelle est la durée de validité d'un permis probatoire ?",
    correct_answer: "c",
    explanation: "LEÇON 1 – 'Le permis de conduire'. Le permis probatoire est valable pour une durée de 3 ans.",
    image_url: "/placeholder.svg?height=300&width=400",
    suggestion: ["1 an", "2 ans", "3 ans"],
  },
]

export default function ExamsPage() {
  const [isStarted, setIsStarted] = useState(false)

  if (!isStarted) {
    return (
      <div className="min-h-screen route-pattern">
        <NavBar />

        {/* Reste du contenu de la page */}
        <div className="route-header bg-white py-4 shadow-md mb-8">
          <div className="container mx-auto px-4">
            <h1 className="text-3xl font-bold text-center text-route-red">Examen du Code de la Route</h1>
            <div className="flex justify-center mt-2">
              <div className="road-line w-32"></div>
            </div>
          </div>
        </div>

        <div className="container mx-auto px-4 py-8 max-w-4xl">
          <Link href="/" className="inline-flex items-center text-route-blue mb-6">
            <ArrowLeft className="mr-2 h-4 w-4" />
            Retour à l'accueil
          </Link>

          <div className="text-center mb-12">
            <p className="text-lg text-muted-foreground max-w-2xl mx-auto mb-8">
              Passez un examen complet dans des conditions réelles. Vous aurez 30 secondes pour répondre à chaque
              question.
            </p>

            <div className="bg-route-yellow/10 border border-route-yellow rounded-lg p-6 mb-8 max-w-2xl mx-auto">
              <div className="flex items-start">
                <AlertTriangle className="h-6 w-6 text-route-yellow mr-3 mt-1 flex-shrink-0" />
                <div className="text-left">
                  <h3 className="font-bold text-lg mb-2">Attention</h3>
                  <p>
                    Cet examen simule les conditions réelles du code de la route. Une fois commencé, vous ne pourrez pas
                    revenir en arrière. Assurez-vous d'être prêt et de disposer de 30 minutes sans interruption.
                  </p>
                </div>
              </div>
            </div>

            <Button
              size="lg"
              onClick={() => setIsStarted(true)}
              className="bg-route-red hover:bg-route-red/90 text-white px-8 py-6 text-lg"
            >
              Commencer l'examen
            </Button>
          </div>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen route-pattern">
      <NavBar />

      <div className="route-header bg-white py-4 shadow-md mb-4">
        <div className="container mx-auto px-4">
          <h1 className="text-3xl font-bold text-center text-route-red">Examen en cours</h1>
          <div className="flex justify-center mt-2">
            <div className="road-line w-32"></div>
          </div>
        </div>
      </div>
      {examQuestions.length > 0 ? (
        <Quiz title="Examen du Code de la Route" questions={examQuestions} type="exam" />
      ) : (
        <div className="container mx-auto px-4 py-8 text-center">
          <p className="text-lg text-gray-600">
            Aucune question d'examen disponible. Veuillez réessayer ultérieurement.
          </p>
        </div>
      )}
    </div>
  )
}
